@@ -1,6 +1,7 @@
 use super::Stack;
 use std::{
     future::Future,
+    marker::PhantomData,
     ops::{Deref, DerefMut},
     task::Context,
 };
@@ -8,21 +9,23 @@ use std::{
 #[repr(C)]
 pub struct AsyncStack<'a, 'b> {
     stack: Stack,
-    context: &'a mut Context<'b>,
+    context: *mut Context<'b>,
     suspended: bool,
+    _context: PhantomData<&'a Context<'b>>,
 }
 
 impl<'a, 'b> AsyncStack<'a, 'b> {
     pub fn new(capacity: usize, context: &'a mut Context<'b>) -> Self {
         Self {
             stack: Stack::new(capacity),
-            context,
+            context: context as *mut Context<'b> as *mut Context<'b>,
             suspended: false,
+            _context: Default::default(),
         }
     }
 
     pub fn context(&mut self) -> &mut Context<'b> {
-        self.context
+        unsafe { &mut *(self.context as *mut Context<'b>) }
     }
 
     pub fn suspend(&mut self, future: impl Future) {
